@@ -6,10 +6,11 @@ describe 'ntp class:', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
 
     # Apply twice to ensure no errors the second time.
     apply_manifest(pp, :catch_failures => true) do |r|
-      expect(r.stderr).to eq("")
+      expect(r.stderr).not_to match(/error/i)
     end
     apply_manifest(pp, :catch_failures => true) do |r|
-      expect(r.stderr).to eq("")
+      expect(r.stderr).not_to eq(/error/i)
+
       expect(r.exit_code).to be_zero
     end
   end
@@ -19,7 +20,7 @@ describe 'ntp class:', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       pp = "class { 'ntp': service_ensure => stopped }"
 
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stderr).to eq("")
+        expect(r.stderr).not_to match(/error/i)
       end
     end
   end
@@ -29,7 +30,7 @@ describe 'ntp class:', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       pp = "class { 'ntp': service_ensure => running }"
 
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stderr).to eq("")
+        expect(r.stderr).not_to match(/error/i)
       end
     end
   end
