@@ -1,5 +1,11 @@
 require 'spec_helper_acceptance'
 
+if (fact('osfamily') == 'Solaris')
+  config = '/etc/inet/ntp.conf'
+else
+  config = '/etc/ntp.conf'
+end
+
 describe 'preferred servers', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   pp = <<-EOS
       class { '::ntp':
@@ -10,15 +16,15 @@ describe 'preferred servers', :unless => UNSUPPORTED_PLATFORMS.include?(fact('os
 
   it 'applies cleanly' do
     apply_manifest(pp, :catch_failures => true) do |r|
-      expect(r.stderr).to eq("")
+      expect(r.stderr).not_to match(/error/i)
     end
   end
 
-  describe file('/etc/ntp.conf') do
+  describe file("#{config}") do
     it { should be_file }
-    it { should contain 'server a' }
-    it { should contain 'server b' }
-    it { should contain 'server c prefer' }
-    it { should contain 'server d prefer' }
+    its(:content) { should match 'server a' }
+    its(:content) { should match 'server b' }
+    its(:content) { should match /server c (iburst\s|)prefer/ }
+    its(:content) { should match /server d (iburst\s|)prefer/ }
   end
 end
